@@ -15,7 +15,7 @@ import { Close as CloseIcon, /*OpenInNew as OpenInNewIcon*/ } from '@mui/icons-m
 
 import { ServerConnection } from '@jupyterlab/services';
 
-import { AccountConnectorsSubMenu, AccountStorageSubMenu, AccountPreferencesSubMenu, AccountLimitsSubMenu, AccountBillingSubMenu } from './settings/SettingsMenu';
+import { AccountIntegrationsSubMenu, AccountStorageSubMenu, AccountPreferencesSubMenu, AccountLimitsSubMenu, AccountBillingSubMenu } from './settings/SettingsMenu';
 import { ShadowedDivider } from '../core';
 import WarningPopup from '../core/WarningPopup';
 import { Colors } from '../Colors';
@@ -30,11 +30,11 @@ const StyledDialog = withStyles({
     },
 })(Dialog);
 
-export const enum Page {
+const enum Page {
     PREFERENCES = 0,
     LIMITS = 1,
     STORAGE = 2,
-    CONNECTORS = 3,
+    INTEGRATIONS = 3,
     BILLING = 4,
 }
 
@@ -251,13 +251,13 @@ export class UserDialog extends React.Component<IProps, IState> {
                                         />
                                         <Tab
                                             disableRipple
-                                            label='Connectors'
+                                            label='Integrations'
                                             sx={{
                                                 padding: '0px',
                                                 minWidth: 'auto',
                                                 minHeight: '36px',
                                             }}
-                                            value={Page.CONNECTORS}
+                                            value={Page.INTEGRATIONS}
                                         />
                                         <Tab
                                             disableRipple
@@ -354,8 +354,8 @@ export class UserDialog extends React.Component<IProps, IState> {
                                             storageCost={this.props.storageCost}
                                             egressCost={this.props.egressCost}
                                         />
-                                    ) : this.state.selectedPanel == Page.CONNECTORS ? (
-                                        <AccountConnectorsSubMenu sx={{flexGrow: 1, overflowY: 'auto'}} />
+                                    ): this.state.selectedPanel == Page.INTEGRATIONS ? (
+                                        <AccountIntegrationsSubMenu sx={{flexGrow: 1, overflowY: 'auto'}} />
                                     ) : this.state.selectedPanel == Page.STORAGE && (
                                         <AccountStorageSubMenu sx={{flexGrow: 1, overflowY: 'auto'}} />
                                     )}
@@ -387,7 +387,7 @@ export class UserDialog extends React.Component<IProps, IState> {
         this._isMounted = true
         Global.setLink(Global.Target.SettingsPopup.PreferencesTab, async () => this.safeSetState({open: true, selectedPanel: Page.PREFERENCES}))
         Global.setLink(Global.Target.SettingsPopup.LimitsTab, async () => this.safeSetState({open: true, selectedPanel: Page.LIMITS}))
-        Global.setLink(Global.Target.SettingsPopup.ConnectorsTab, async () => this.safeSetState({open: true, selectedPanel: Page.CONNECTORS}))
+        Global.setLink(Global.Target.SettingsPopup.IntegrationsTab, async () => this.safeSetState({open: true, selectedPanel: Page.INTEGRATIONS}))
         Global.setLink(Global.Target.SettingsPopup.StorageTab, async () => this.safeSetState({open: true, selectedPanel: Page.STORAGE}))
         Global.setLink(Global.Target.SettingsPopup.BillingTab, async () => this.safeSetState({open: true, selectedPanel: Page.BILLING}))
     }
