@@ -157,7 +157,7 @@ export class AddDataConnectorsPopup extends React.Component<IProps, IState> {
                             variant='contained'
                             color='primary'
                             onClick={() => {
-                                Global.followLink(Global.Target.SettingsPopup.ConnectorsTab)
+                                Global.followLink(Global.Target.SettingsPopup.IntegrationsTab)
                                 this.safeSetState({open: false})
                             }}
                             endIcon={<OpenInNew />}
