@@ -41,6 +41,7 @@ const fileTypes: FileType[] = [
     {extension: '.html',    mime: 'text/html',                      icon: <html5Icon.react display='block'/>, alternativeExtensions: ['.htm']},
     {extension: '.ico',     mime: 'image/vnd.microsoft.icon',       icon: <imageIcon.react display='block'/>},
     {extension: '.ics',     mime: 'text/calendar',                  icon: undefined},
+    {extension: '.ipynb',   mime: 'text/json',                      icon: <notebookIcon.react display='block'/>},
     {extension: '.jar',     mime: 'application/java-archive',       icon: undefined},
     {extension: '.jpeg',    mime: 'image/jpeg',                     icon: <imageIcon.react display='block'/>, alternativeExtensions: ['.jpg']},
     {extension: '.js',      mime: 'text/javascript',                icon: undefined},
@@ -93,6 +94,7 @@ const fileTypes: FileType[] = [
 interface IProps {
     fileType: 'notebook' | 'file' | 'directory'
     mimetype: string
+    extension: string
     sx?: SxProps<Theme>
 }
 
@@ -105,7 +107,7 @@ export default class DirListingItemIcon extends React.Component<IProps, IState>
     }
 
     public render = (): JSX.Element => {
-		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
+		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')')
         return (
             <SPAN className='jp-DirListing-itemIcon' sx={this.props.sx}>
                 {this.props.fileType === 'notebook' ? (
@@ -115,11 +117,17 @@ export default class DirListingItemIcon extends React.Component<IProps, IState>
                 ) : (() => {
                     for (const fileType of fileTypes) {
                         if (fileType.mime === this.props.mimetype) return fileType.icon || <fileIcon.react display='block'/>
+                        if (fileType.extension === '.' + this.props.extension) return fileType.icon || <fileIcon.react display='block'/>
                         if (fileType.alternativeMimes !== undefined) {
                             for (const alternativeMime of fileType.alternativeMimes) {
                                 if (alternativeMime === this.props.mimetype) return fileType.icon || <fileIcon.react display='block'/>;
                             }
                         }
+                        if (fileType.alternativeExtensions !== undefined) {
+                            for (const alternativeExtension of fileType.alternativeExtensions) {
+                                if (alternativeExtension === '.' + this.props.extension) return fileType.icon || <fileIcon.react display='block'/>;
+                            }
+                        }
                     }
                     return <fileIcon.react display='block'/>
                 })()}
