@@ -6,14 +6,17 @@
 **/
 
 import * as React from 'react'
-import { Global } from '../Global';
+import { Global, PRE } from '../Global';
+
+import { SxProps, Theme } from '@mui/system';
+
 import { defaultSanitizer } from '@jupyterlab/apputils';
+
 import escape from 'lodash.escape';
-import { CSSProperties } from '@material-ui/core/styles/withStyles';
 
 interface IProps {
     text: string
-    style?: CSSProperties
+    sx?: SxProps<Theme>
 }
 interface IState {}
 
@@ -22,7 +25,7 @@ export class AnsiLink extends React.Component<IProps, IState> {
     public render = (): JSX.Element => {
         if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
-            <pre style={Object.assign({}, this.props.style)} dangerouslySetInnerHTML={{ __html: autolink(defaultSanitizer.sanitize(ansiSpan(this.props.text))) }} />
+            <PRE sx={Object.assign({}, this.props.sx)} dangerouslySetInnerHTML={{ __html: autolink(defaultSanitizer.sanitize(ansiSpan(this.props.text))) }} />
         )
     }
 }
@@ -122,7 +125,7 @@ function pushColoredChunk(
         }
 
         if (classes.length || styles.length) {
-            out.push('<span');
+            out.push('<SPAN');
             if (classes.length) {
                 out.push(` class="${classes.join(' ')}"`);
             }
@@ -131,7 +134,7 @@ function pushColoredChunk(
             }
             out.push('>');
             out.push(chunk);
-            out.push('</span>');
+            out.push('</SPAN>');
         } else {
             out.push(chunk);
         }
@@ -183,7 +186,7 @@ function getExtendedColors(numbers: Array<number>): number | Array<number> {
 }
 
 /**
-   * Transform ANSI color escape codes into HTML <span> tags with CSS
+   * Transform ANSI color escape codes into HTML <SPAN> tags with CSS
    * classes such as "ansi-green-intense-fg".
    * The actual colors used are set in the CSS file.
    * This also removes non-color escape sequences.
@@ -322,4 +325,4 @@ function ansiSpan(str: string): string {
         }
     }
     return out.join('');
-}
\ No newline at end of file
+}
