@@ -124,7 +124,7 @@ export class BaseConnectorPopup extends React.Component<IProps, IState> {
             method: 'POST',
             body: JSON.stringify({
                 name: this.state.name,
-                info: JSON.stringify(Object.assign({ integrationType: IntegrationType.DATA_CONNECTOR, dataService: this.props.dataService }, this.props.getInfo())),
+                info: JSON.stringify(Object.assign({ integrationType: IntegrationType.DATA_CONNECTOR, dataService: this.props.dataService, downloadPath: this.props.downloadPath }, this.props.getInfo())),
             }),
         };
         ServerConnection.makeRequest(
