@@ -6,13 +6,21 @@
 **/
 
 export class FileUploadConfig {
+    public hash: string;
     public path: string;
+    public size: number;
+    public created: Date;
+    public lastModified: Date;
     public type: 'file' | 'notebook' | 'directory';
     public mimetype: string;
     public enabled: boolean;
 
     constructor(map: any) {
+        this.hash = map.hash;
         this.path = map.path;
+        this.size = map.size;
+        this.created = map.created;
+        this.lastModified = map.lastModified;
         this.type = map.type || 'file';
         this.mimetype = map.mimetype || 'text/plain';
         this.enabled = map.enabled == undefined ? false : map.enabled
