@@ -17,6 +17,13 @@ export const providerOptions = {
     info: { backgroundColor: Colors.PRIMARY + ' !important' },
 }
 
+export enum SnackbarActionType {
+    DISMISS = "dismiss",
+	SUBSCRIBE = "subscribe",
+	ENABLE_AUTO_ADD_ONS = "enable auto add ons",
+	AUTO_REMOVE = "auto remove",
+}
+
 export class Snackbar {
     message: string;
     options: OptionsObject;
@@ -24,12 +31,12 @@ export class Snackbar {
     private standardOptions: OptionsObject = {
         anchorOrigin: {
             vertical: 'bottom',
-            horizontal: 'center',
+            horizontal: 'right',
         },
     }
 
     constructor(message: string, options: OptionsObject) {
         this.message = message;
-        this.options = Object.assign({}, options, this.standardOptions);
+        this.options = Object.assign({ key: message, preventDuplicate: true }, options, this.standardOptions);
     }
-}
\ No newline at end of file
+}
