@@ -944,13 +944,14 @@ export class User {
 
 	private getUserInformation() {
 		if (Global.user == null) return
-
+		
 		const settings = ServerConnection.makeSettings();
 		const url = settings.baseUrl + "optumi/get-user-information";
 		const init = {
 			method: 'POST',
 			body: JSON.stringify({
 				includeAll: false,
+				timestamp: new Date().toISOString(),
 			})
 		};
 		ServerConnection.makeRequest(
@@ -962,6 +963,12 @@ export class User {
 			return response.json();
 		}).then((body: any) => {
 			if (body) {
+				// We don't want to poll while we are setting information, since it might override the value being set, so skip this iteration
+				if (body.timestamp && (new Date(body.timestamp).getTime() < this.lastSetUserInformationTimestamp.getTime())) {
+					setTimeout(() => this.getUserInformation())
+					return
+				}
+
 				if (body.name) this._name = body.name
 				if (body.phoneNumber) this._phoneNumber = body.phoneNumber
 				if (body.intent) this._intent = +body.intent
@@ -1133,7 +1140,9 @@ export class User {
 		}
 	}
 
+	private lastSetUserInformationTimestamp = new Date(0)
 	private setUserInformation(param: string, value: any) {
+		this.lastSetUserInformationTimestamp = new Date();
 		const settings = ServerConnection.makeSettings();
 		const url = settings.baseUrl + "optumi/set-user-information";
 		const init = {
